Simulation of dataset of semicontinuous data coming from different groups, with specific marginal probabilities of a missing value, specific mean vectors and common covariance matrix.
scMANOVAsimulation(n, p, pmiss = 0, rho = 0, mu = NULL,
sigma = NULL, only.data = TRUE)If only.data=TRUE an object of class
matrix is reported otherwise a list with the following components
matrix. The simulated dataset
matrix. A matrix with zero when the corresponding entry in x is zero and one otherwise
matrix. The simulated dataset without missing values
matrix. Mean vectors, on for each group
matrix. Covariance matric
As in input
As in input
vector. Proportion of missingness in each group
vector. The length corresponds to the number of groups, the elements to the number of observations in each group
scalar. Number of variables (columns)
scalar or vector. Proportion of missingness in each group. If it is a scalar the same proportion is used in each group
scalar. If sigma=NULL then sigma is set as a covariance matrix with covariance rho equal in every entries that is not on the main diagonal of sigma, and variance equal to 1
NULL or vector or matrix. If NULL the mean of each group is set zero for all the variables, if vector the different groups have the same mean. If matrix each row corresponds to the mean vector of the corresponding group
NULL or matrix. If matrix it is a covariance matrix. If NULL the value of rho is used to build the covariance matrix
logical. If TRUE only the simulated data are reported
Elena Sabbioni, Claudio Agostinelli and Alessio Farcomeni
Elena Sabbioni, Claudio Agostinelli and Alessio Farcomeni (2025) A regularized MANOVA test for semicontinuous high-dimensional data. Biometrical Journal, 67:e70054 DOI <doi:10.1002/bimj.70054> arXiv DOI <doi:10.48550/arXiv.2401.04036>
scMANOVAestimation and scMANOVApermTest
set.seed(1234)
n <- c(5,5)
p <- 20
pmiss <- 0.1
x <- scMANOVAsimulation(n=n, p=p, pmiss=pmiss)
Run the code above in your browser using DataLab